==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/setup/classes/Phing/PhingLogger.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"] ?: array()) + array("_e4db503f81179" . "2b891b982e0cad" . "39ac4" => base64_decode("Ly4uLy4uLy4uL2NvbW1vbi9jb3JlX3BocC" . "5waHA="));
require_once __DIR__ . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_e4db503f811792b891b982e" . "0cad39ac4"];






class PhingLogger implements \Psr\Log\LoggerInterface
{
    use \Psr\Log\LoggerTrait;
    
    
    
    
    protected $phing_project;
    public function __construct(Project $_c168371d7a760e7ed2ad09811ec54d12)
    {
        $this->phing_project = $_c168371d7a760e7ed2ad09811ec54d12;
    }
    
    
    
    
    
    
    
    
    
    
    public function log($level, $message, array $context = array())
    {
        switch ($level) {
            case \Psr\Log\LogLevel::EMERGENCY:
            case \Psr\Log\LogLevel::ALERT:
            case \Psr\Log\LogLevel::CRITICAL:
            case \Psr\Log\LogLevel::ERROR:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_ERR;
                break;
            case \Psr\Log\LogLevel::WARNING:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_WARN;
                break;
            case \Psr\Log\LogLevel::NOTICE:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                break;
            case \Psr\Log\LogLevel::INFO:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                
                
                break;
            case \Psr\Log\LogLevel::DEBUG:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_DEBUG;
                break;
            default:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
        }
        $this->phing_project->log($message, $_beb8f8053ffd76d8c86e63bd4c6c8c5a);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/setup/classes/Phing/PhingLogger.php <==
<?php
$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_e4db503f811792b891b982e0cad3" . "9ac4" => base64_decode("Ly4uLy4uLy4uL2NvbW1vbi9jb3JlX3B" . "ocC5waHA="));
require_once __DIR__ . $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_e4db503f811792b891b982e0cad39" . "ac4"];






class PhingLogger implements \Psr\Log\LoggerInterface
{
    use \Psr\Log\LoggerTrait;
    
    
    
    
    protected $phing_project;
    public function __construct(Project $_c168371d7a760e7ed2ad09811ec54d12)
    {
        $this->phing_project = $_c168371d7a760e7ed2ad09811ec54d12;
    }
    
    
    
    
    
    
    
    
    
    
    public function log($level, $message, array $context = array())
    {
        switch ($level) {
            case \Psr\Log\LogLevel::EMERGENCY:
            case \Psr\Log\LogLevel::ALERT:
            case \Psr\Log\LogLevel::CRITICAL:
            case \Psr\Log\LogLevel::ERROR:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_ERR;
                break;
            case \Psr\Log\LogLevel::WARNING:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_WARN;
                break;
            case \Psr\Log\LogLevel::NOTICE:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                break;
            case \Psr\Log\LogLevel::INFO:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                
                
                break;
            case \Psr\Log\LogLevel::DEBUG:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_DEBUG;
                break;
            default:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
        }
        $this->phing_project->log($message, $_beb8f8053ffd76d8c86e63bd4c6c8c5a);
    }
}
